v1.0.7
=======
- added functions: 
    * :func:`rohub.ros_list_keywords`
    * :func:`rohub.ros_add_keywords`
    * :func:`rohub.ros_delete_keywords`
    * :func:`rohub.ros_set_keywords`
    * :func:`ResearchObject.list_keywords`
    * :func:`ResarchObject.add_keywords`
    * :func:`ResarchObject.set_keywords`
    * :func:`ResarchObject.delete_keywords`
    * :func:`rohub.ros_make_golden`
    * :func:`rohub.ros_undo_golden`
    * :func:`ResarchObject.make_golden`
    * :func:`ResarchObject.undo_golden`
- modification to :func:`rohub.zenodo_list_funders` and :func:`rohub.zenodo_list_grants`. Now both allow to query zenodo results against provided value. The resuls are displayed as table (Panda's DataFrame)
- doctsring improvements for :func:`rohub.ros_upload`, :func:`rohub.ros_snapshot` and :func:`rohub.ros_archive`
